summaryrefslogtreecommitdiffstats
path: root/kig
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-02-19 04:52:53 +0100
committerSlávek Banko <slavek.banko@axis.cz>2013-02-19 04:52:53 +0100
commit8216a980535a86e006855409c5620530061724de (patch)
tree03f9a8aa9dcf563ee4f1bf2151212bdce59e1d72 /kig
parent75ba599ac4ab2b602ef2582f9e0612b077d35bd2 (diff)
downloadtdeedu-8216a980535a86e006855409c5620530061724de.tar.gz
tdeedu-8216a980535a86e006855409c5620530061724de.zip
Fix unintended rename of many various *klist*
Diffstat (limited to 'kig')
-rw-r--r--kig/objects/polygon_imp.cc30
-rw-r--r--kig/scripting/python_scripter.cc4
2 files changed, 17 insertions, 17 deletions
diff --git a/kig/scripting/python_scripter.cc b/kig/scripting/python_scripter.cc
index 81f377ac..7e833d5c 100644
--- a/kig/scripting/python_scripter.cc
+++ b/kig/scripting/python_scripter.cc
@@ -539,12 +539,12 @@ void PythonScripter::saveErrors()
object printexcfunc = d->mainnamespace[ "traceback" ].attr( "format_exception" );
- list tracebactdelist = extract<list>( printexcfunc( exctype, excvalue, exctraceback ) )();
+ list tracebacklist = extract<list>( printexcfunc( exctype, excvalue, exctraceback ) )();
str tracebackstr( "" );
while ( true )
{
try {
- str s = extract<str>( tracebactdelist.pop() );
+ str s = extract<str>( tracebacklist.pop() );
tracebackstr += s;
}
catch( ... )
diff --git a/kig/objects/polygon_imp.cc b/kig/objects/polygon_imp.cc
index dd3ffa44..43ee16f9 100644
--- a/kig/objects/polygon_imp.cc
+++ b/kig/objects/polygon_imp.cc
@@ -498,34 +498,34 @@ std::vector<Coordinate> computeConvexHull( const std::vector<Coordinate>& points
*/
if ( points.size() < 3 ) return points;
- std::vector<Coordinate> wortdelist = points;
+ std::vector<Coordinate> worklist = points;
std::vector<Coordinate> result;
- double ymin = wortdelist[0].y;
+ double ymin = worklist[0].y;
uint imin = 0;
- for ( uint i = 1; i < wortdelist.size(); ++i )
+ for ( uint i = 1; i < worklist.size(); ++i )
{
- if ( wortdelist[i].y < ymin )
+ if ( worklist[i].y < ymin )
{
- ymin = wortdelist[i].y;
+ ymin = worklist[i].y;
imin = i;
}
}
- // wortdelist[imin] is definitely on the convex hull, let's start from there
- result.push_back( wortdelist[imin] );
- Coordinate startpoint = wortdelist[imin];
- Coordinate apoint = wortdelist[imin];
+ // worklist[imin] is definitely on the convex hull, let's start from there
+ result.push_back( worklist[imin] );
+ Coordinate startpoint = worklist[imin];
+ Coordinate apoint = worklist[imin];
double aangle = 0.0;
- while ( ! wortdelist.empty() )
+ while ( ! worklist.empty() )
{
int besti = -1;
double anglemin = 10000.0;
- for ( uint i = 0; i < wortdelist.size(); ++i )
+ for ( uint i = 0; i < worklist.size(); ++i )
{
- if ( wortdelist[i] == apoint ) continue;
- Coordinate v = wortdelist[i] - apoint;
+ if ( worklist[i] == apoint ) continue;
+ Coordinate v = worklist[i] - apoint;
double angle = std::atan2( v.y, v.x );
while ( angle < aangle ) angle += 2*M_PI;
if ( angle < anglemin )
@@ -536,14 +536,14 @@ std::vector<Coordinate> computeConvexHull( const std::vector<Coordinate>& points
}
if ( besti < 0 ) return result; // this happens, e.g. if all points coincide
- apoint = wortdelist[besti];
+ apoint = worklist[besti];
aangle = anglemin;
if ( apoint == startpoint )
{
return result;
}
result.push_back( apoint );
- wortdelist.erase( wortdelist.begin() + besti, wortdelist.begin() + besti + 1 );
+ worklist.erase( worklist.begin() + besti, worklist.begin() + besti + 1 );
}
assert( false );
return result;